// ETELMM.H
//
// Author:  Nickolay Golubev
// Contact: 2nike@mail.ru
// Version: 0.03
// Updated: 19.09.2003
// 


#if !defined(__ETELMM_H__)
#define __ETELMM_H__

#if !defined(__E32BASE_H__)
#include <E32BASE.H>
#endif

#if !defined(__ETEL_H__)
#include <ETEL.H>
#endif

#if !defined(__MM_HOLD_H__)
#include <MM_HOLD.H>
#endif

const TUint KPhoneManufacturerIdSize = 50;
const TUint KPhoneModelIdSize = 50;
const TUint KPhoneRevisionIdSize = 50;
const TUint KPhoneSerialNumberSize = 50;

class RMobilePhone : public RPhone
        {
public:
        class TMultimodeType
                {
        public:
                IMPORT_C TInt ExtensionId();
        protected:
                IMPORT_C TMultimodeType();
                void InternalizeL(RReadStream& aStream);
                void ExternalizeL(RWriteStream& aStream) const;
                };

        class TMobilePhoneIdentityV1 : public TMultimodeType
                {
        public:
                IMPORT_C TMobilePhoneIdentityV1();
                TBuf<KPhoneManufacturerIdSize> iManufacturer;
                TBuf<KPhoneModelIdSize> iModel;
                TBuf<KPhoneRevisionIdSize> iRevision;
                TBuf<KPhoneSerialNumberSize> iSerialNumber;
                };                                                      

public:
        enum TMobilePhoneIdentityCaps
                {
                KCapsGetManufacturer = 0x00000001,   // Phone can return the identity of its manufacturer. 
                KCapsGetModel        = 0x00000002,   // Phone can return the identity of its model.        
                KCapsGetRevision     = 0x00000004,   // Phone can return the identity of its revision.     
                KCapsGetSerialNumber = 0x00000008,   // Phone can return the identity of its serial number.
                KCapsGetSubscriberId = 0x00000010    // Phone can return the identity of its subscriber.   
                };

        enum TMobileTON
                {
                EUnknownNumber,                 // User or the network has no knowledge of the type of number.
                EInternationalNumber,           // International number.
                ENationalNumber,                // National number.
                ENetworkSpecificNumber,         // Administration/service number specific to the serving network, e.g. used to access an operator.
                ESubscriberNumber,              // Subscriber number.
                EAlphanumericNumber,            // Alphanumeric number coded according to 3GPP TS 123 038 GSM 7-bit default alphabet.
                EAbbreviatedNumber              // Abbreviated number.
                };
        
        enum TMobileNPI
                {
                EUnknownNumberingPlan,          // User or the network has no knowledge of the numbering plan.
                EIsdnNumberPlan,                // ISDN/telephony numbering plan.
                EDataNumberPlan,                // Data numbering plan.
                ETelexNumberPlan,               // Telex numbering plan.
                EServiceCentreSpecificPlan1,    // Service centre specific plan used to indicate a numbering plan specific to external Short Message entities attached to the SMSC.
                EServiceCentreSpecificPlan2,    // Service centre specific plan used to indicate a numbering plan specific to external Short Message entities attached to the SMSC.
                ENationalNumberPlan,            // National numbering plan.
                EPrivateNumberPlan,             // Private numbering plan.
                EERMESNumberPlan                // ERMES numbering plan.
                };

        enum
        {
                KMaxMobilePasswordSize = 50, // Maximum size of the mobile phone password.
                KMaxMobileNameSize = 50, // Maximum size of a name.
                KMaxMobileTelNumberSize =21 // Maximum size of a telephone number.
        };
 
        typedef TBuf<KMaxMobileNameSize> TMobileName;

        class TMobileAddress
        {
        public:
                IMPORT_C TMobileAddress();
                TBuf <KMaxMobileTelNumberSize> iTelNumber;
                TMobileNPI iNumberPlan;
                TMobileTON iTypeOfNumber;
                IMPORT_C void InternalizeL(RReadStream& aStream);
                IMPORT_C void ExternalizeL(RWriteStream& aStream) const;
        };
public:
        IMPORT_C RMobilePhone();
        IMPORT_C TInt GetIdentityCaps(TUint32& aCaps) const;
        IMPORT_C void GetPhoneId(TRequestStatus& aReqStatus, TMobilePhoneIdentityV1& aId) const;

protected:
        IMPORT_C void ConstructL();
        IMPORT_C void Destruct();
        };

class RMobilePhoneStore : public RTelSubSessionBase
        {
public: 
        enum TMobileSmsStoreStatus
                {
                        EStoredMessageUnknownStatus,    // The status of the SMS is unknown.
                        EStoredMessageUnread,           // The SMS is stored phone-side. It is an incoming message that has not been read yet.
                        EStoredMessageRead,             // The SMS is stored phone-side. It is an incoming message that has already been read.
                        EStoredMessageUnsent,           // The SMS is stored phone-side. It is an outgoing message that has not been sent yet.
                        EStoredMessageSent,             // The SMS is stored phone-side. It is an outgoing message that has already been sent but a delivery/status report has either not been received yet or was not requested in the first place.
                        EStoredMessageDelivered,        // The SMS is stored phone-side. It is an outgoing message that has already been sent and a delivery/status report has been received
                };
        class TMobilePhoneStoreEntryV1 : public RMobilePhone::TMultimodeType
        {
        public: 
                TInt iIndex;
                IMPORT_C void InternalizeL(RReadStream& aStream);
                IMPORT_C void ExternalizeL(RWriteStream& aStream) const;

        protected:
                IMPORT_C TMobilePhoneStoreEntryV1();
        };

        class TMobileSmsEntryV1 : public RMobilePhoneStore::TMobilePhoneStoreEntryV1
        {
        public: 
                TMobileSmsStoreStatus iMsgStatus;
                IMPORT_C void InternalizeL(RReadStream& aStream);
                IMPORT_C void ExternalizeL(RWriteStream& aStream) const;
        protected:
                IMPORT_C TMobileSmsEntryV1();
        };

        class TMobileGsmSmsEntryV1 : public TMobileSmsEntryV1
        {
                IMPORT_C TMobileGsmSmsEntryV1();
        };


public:
        IMPORT_C RMobilePhoneStore();
protected:
        IMPORT_C void BaseConstruct(CMobilePhoneStorePtrHolder* aPtrHolder);
        IMPORT_C void Destruct();
        };


class RMobileSmsStore : public RMobilePhoneStore
        {
public:
        IMPORT_C RMobileSmsStore();
protected:
        IMPORT_C void ConstructL();
private:
        IMPORT_C RMobileSmsStore(const RMobileSmsStore&);
        };

class RMobileSmsMessaging : public RTelSubSessionBase
        {
public:
        enum
        {
                KGsmTpduSize = 160, // Size of the GSM/WCDMA message buffer.
                KCdmaTpduSize = 160 //Size of the CDMA message buffer.
        };
        enum TMobileSmsBearer
        {
                ESmsBearerPacketOnly,           // SMS messages will only be sent over a packet-switched (GPRS) network.
                ESmsBearerCircuitOnly,          // SMS messages will only be sent over a circuit-switched (GSM) network.
                ESmsBearerPacketPreferred,      // SMS messages will be sent over the packet-switched (GPRS) network if possible, otherwise over circuit-switched (GSM) network.
                ESmsBearerCircuitPreferred,     // SMS messages will be sent over the circuit-switched (GSM) network if possible, otherwise over packet-switched (GPRS) network.
        };

        typedef TBuf8<KGsmTpduSize> TMobileSmsGsmTpdu;
public:
        IMPORT_C RMobileSmsMessaging();
protected:
        IMPORT_C void ConstructL();
        IMPORT_C void Destruct();
        };



#endif
